from pydantic import BaseSettings
from functools import lru_cache
import os


class Settings(BaseSettings):
    APP_NAME: str
    ENV: str
    LOKI: str

    class Config:
        env_file = os.getenv("ENV_FILE") or ".env.dev"


@lru_cache()
def get_settings():
    return Settings()



import logging
from typing import Union
import logging_loki
from multiprocessing import Queue
from logger_bro.settings import get_settings

settings = get_settings()

handler = logging_loki.LokiQueueHandler(
    Queue(-1),
    url=settings.LOKI,
    # TODO: Create versioning for the logger. We need different logs
    # for v1 and v2
    tags={"application": "WSMA", "version": "v1"},
    # Version is used internally by the client. It is irrelevant
    # to the api version
    version="1",
)


logger = logging.getLogger("loki")
logger.setLevel(level=logging.INFO)
logger.addHandler(handler)


def get_loki_logger():
    return logging.getLogger("loki")


def log_exception(exc: Exception):
    logger = get_loki_logger()
    logger.exception(
        exc, extra={"tags": {"level": logging.getLevelName(logging.ERROR)},},
    )



from setuptools import setup, find_packages

VERSION = "0.0.2"
DESCRIPTION = "A logging package using Loki for Python"

print(find_packages())

setup(
    name="logger_bro",
    version=VERSION,
    author="Charis Giaralis",
    author_email="charis.giaralis@gmail.com",
    description=DESCRIPTION,
    packages=find_packages(),
    install_requires=[],
    keywords=["python", "logger"],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Education",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ],
)
